==> sleepanalyser_2.1-57.tar.gz: sleepanalyser-2.1/src/opt/SleepAnalyser/kht_report.py <==
# -*- coding: utf-8 -*-

###########################################################################
## File:        kht_report.py
## Description: This file includes the error handling routine
##Copyright:    Kerthan
###########################################################################

import sys
import traceback
#import hildon
#import gtk
#import osso
import string

from PyQt4.QtCore import *
from PyQt4.QtGui import *

import data

from functions_record import *
from functions_alarm import *



#Here is the installation of the hook. Each time a untrapped/unmanaged exception will
#happen my_excepthook will be called.
def install_excepthook(app_name,app_version):

    def my_excepthook(exctype, value, tb):

        print "--> THE ERROR OCCURED HERE <--\n"
        print "-----------------------------------------------------------------------------"

        delete_all_Alarms()

        #traceback give us all the errors information message like the method, file line ... everything like
        #we have in the python interpreter
        s = ''.join(traceback.format_exception(exctype, value, tb))
        #      formatted_text = str(APP_NAME)+'Version '+str(APP_VERSION) + '\nTrace : ' + s + '\n' + 'Comments : '
        formatted_text = s
        #here is just my own gtk dialog you can replace it by what you want
        ErrorReportDialog(formatted_text)

    sys.excepthook = my_excepthook





def error():
    context = osso.Context('net.khertan.bugreporter','1.0.0', False)
    note = osso.SystemNote(context)
    result = note.system_note_infoprint("Error occurs during the report")





#A small Qt Dialog
def ErrorReportDialog(trace,txt_email=None):
    print "-----------------------------------------------------------------------------\n"
#    item, ok = QInputDialog.getItem(None, 'Select voice type', "", "aabcde", 0, False)
    print "## Oops! An error occurred!"
    print "Below is a print out of the record data as well as the configuration:"
    PrintRecordData(False)
    PrintConfig()
    print trace

    txt=string.replace(trace, "  File \"/opt/SleepAnalyser/", "\"")
    arr=txt.split("\n")
#    print arr
#    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
    txt="SleepAnalyser crashed and has to be closed.\n\nError:\n"
    for i in range(len(arr)-7, len(arr)-1): txt=txt+arr[i]+"\n"

    QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt, QMessageBox.Ok) #Max 11 lines in dialog!
#    r=QInputDialog.getText(None, "Add Note", trace, QLineEdit.Normal, "---\nlll\nkkk")


    quit() #quit application




#Small test of a use from a about menu for example
if __name__ == "__main__":
    pass

==> sleepanalyser_2.1-63.tar.gz: sleepanalyser-2.1/src/opt/SleepAnalyser/kht_report.py <==
# -*- coding: utf-8 -*-

###########################################################################
## File:        kht_report.py
## Description: This file includes the error handling routine
##Copyright:    Kerthan
###########################################################################

import sys
import traceback
#import hildon
#import gtk
#import osso
import string

from PyQt4.QtCore import *
from PyQt4.QtGui import *

import data

from functions_record import *
from functions_alarm import *



#Here is the installation of the hook. Each time a untrapped/unmanaged exception will
#happen my_excepthook will be called.
def install_excepthook(app_name,app_version):

    def my_excepthook(exctype, value, tb):
        print "\n--> THE ERROR OCCURED HERE <--\n"
        print "-----------------------------------------------------------------------------"
        print "Cleanup..."

#        delete_all_Alarms()
##  NOTE: Do not delete alarms in case of a crash!!!

        #traceback give us all the errors information message like the method, file line ... everything like
        #we have in the python interpreter
        s = ''.join(traceback.format_exception(exctype, value, tb))
        #      formatted_text = str(APP_NAME)+'Version '+str(APP_VERSION) + '\nTrace : ' + s + '\n' + 'Comments : '
        formatted_text = s
        #here is just my own gtk dialog you can replace it by what you want
        ErrorReportDialog(formatted_text)

    sys.excepthook = my_excepthook





def error():
    context = osso.Context('net.khertan.bugreporter','1.0.0', False)
    note = osso.SystemNote(context)
    result = note.system_note_infoprint("Error occurs during the report")





#A small Qt Dialog
def ErrorReportDialog(trace,txt_email=None):
    print "-----------------------------------------------------------------------------\n"
#    item, ok = QInputDialog.getItem(None, 'Select voice type', "", "aabcde", 0, False)
    print "## Oops! An error occurred!"
    print "Below is a print out of the record data as well as the configuration:"
    PrintRecordData(False)
    PrintConfig()
    print trace

    txt=string.replace(trace, "  File \"/opt/SleepAnalyser/", "\"")
    arr=txt.split("\n")
#    print arr
#    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
    txt="SleepAnalyser crashed and has to be closed.\n\n"
    for i in range(len(arr)-7, len(arr)-1): txt=txt+arr[i]+"\n"

    QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt, QMessageBox.Ok) #Max 11 lines in dialog!
#    r=QInputDialog.getText(None, "Add Note", trace, QLineEdit.Normal, "---\nlll\nkkk")


    quit() #quit application




#Small test of a use from a about menu for example
if __name__ == "__main__":
    pass
